#include <ESP8266WiFi.h>

const char* ssid = "Your WiFi SSID"; 
const char* password = "Your WiFi Password";

// Set up a web server port
WiFiServer server(80);

// HTTP Variable to store requests
String header;

String relay1State = "off";
String relay2State = "off";
String relay3State = "off";
String relay4State = "off";

// Pins used to control relays
const int relay1 = 5; // D1
const int relay2 = 4; // D2
const int relay3 = 0; // D3
const int relay4 = 2; // D4

void setup() {
Serial.begin(115200);

// Select the relevant PIN modes
pinMode(relay1, OUTPUT); 
pinMode(relay2, OUTPUT);
pinMode(relay3, OUTPUT);
pinMode(relay4, OUTPUT);

// Set the relays to on by default
digitalWrite(relay1, HIGH); 
digitalWrite(relay2, HIGH);
digitalWrite(relay3, HIGH);
digitalWrite(relay4, HIGH);

Serial.print("Connecting to ");
Serial.println(ssid);
WiFi.begin(ssid, password); // We will connect with the entered name and password
while (WiFi.status() != WL_CONNECTED) {
delay(500);
Serial.print(".");
}
Serial.println("");
Serial.println("WiFi connected.");
Serial.println("IP address: ");
Serial.println(WiFi.localIP()); //IP address will be shown
server.begin();
}

void loop() {
WiFiClient client = server.available(); // Web server starts

if (client) {
Serial.println("New Client.");
String currentLine = "";
while (client.connected()) {
if (client.available()) {
char c = client.read();
Serial.write(c);
header += c;
if (c == '\n') {

if (currentLine.length() == 0) {

client.println("HTTP/1.1 200 OK");
client.println("Content-type:text/html");
client.println("Connection: close");
client.println();

//The PIN will be activated according to the received requests

if (header.indexOf("GET /relay1/on") >= 0)
{
Serial.println("GPIO 5 on");
relay1State = "on";
digitalWrite(relay1, LOW);
}
else if (header.indexOf("GET /relay1/off") >= 0)
{
Serial.println("GPIO 5 off");
relay1State = "off";
digitalWrite(relay1, HIGH);
}
else if (header.indexOf("GET /relay2/on") >= 0) {
Serial.println("GPIO 4 on");
relay2State = "on";
digitalWrite(relay2, LOW);
}
else if (header.indexOf("GET /relay2/off") >= 0) {
Serial.println("GPIO 4 off");
relay2State = "off";
digitalWrite(relay2, HIGH);
}
else if (header.indexOf("GET /relay3/on") >= 0)
{
Serial.println("GPIO 0 on");
relay3State = "on";
digitalWrite(relay3, LOW);
}
else if (header.indexOf("GET /relay3/off") >= 0)
{
Serial.println("GPIO 0 off");
relay3State = "off";
digitalWrite(relay3, HIGH);
}
else if (header.indexOf("GET /relay4/on") >= 0) {
Serial.println("GPIO 2 on");
relay4State = "on";
digitalWrite(relay4, LOW);
}
else if (header.indexOf("GET /relay4/off") >= 0) {
Serial.println("GPIO 2 off");
relay4State = "off";
digitalWrite(relay4, HIGH);
}

// HTML Page
client.println("<!DOCTYPE html><html>");
client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");
client.println("<title>WebServer based Device Controller</title>");
client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");

// You can customize the values ​​according to your needs
client.println("<style>html, body {background-color: #e0ebcd; font-family: Helvetica; display: block; color: #1336dd; margin: 0px auto; text-align: center;}");
client.println(".button { background-color: #30f040; color: black; padding: 12px 40px;");
client.println("text-decoration: none; font-size: 20px; margin: auto; cursor: pointer;}");
client.println(".button2 {background-color: red; color: black; padding: 12px 40px;}");
client.println(".textbox {width: 80px; padding: 16px 20px 0px 24px; background-image: linear-gradient(180deg, #fff, #ddd 40%, #ccc);}");
client.println(".mytext {font-size: 16px; font-weight:bold; font-family:Arial ; text-align: center;}");
client.println(".headertext{ font-weight:bold; font-family:Arial ; text-align: center; color: brown ;}");
client.println("#container {width: 100%; height: 100%; margin-left: 5px; margin-top: 20px; padding: 10px; display: -webkit-flex; -webkit-justify-content: center; display: flex; justify-content: center;} ");
client.println("</style></head>");
client.println("<body><h1><u><div class = \"headertext\"> WebServer based Device Controller</u></h1>");

// The elements inside the web page are defined

client.println("<div id=\"container\">");
client.println("<p><div class=\"textbox mytext\">DEVICE 1</div>");
if (relay1State == "off") {
client.println("<a href=\"/relay1/on\"><button class=\"button\">ON</button></a></p>");
} 
else 
{
client.println("<a href=\"/relay1/off\"><button class=\"button button2\">OFF</button></a></p>");
}

client.println("</div>");
client.println("<div id=\"container\">");
client.println("<p><div class=\"textbox mytext\">DEVICE 2</div>");

if (relay2State == "off") {
client.println("<a href=\"/relay2/on\"><button class=\"button\">ON</button></a></p>");
} else {
client.println("<a href=\"/relay2/off\"><button class=\"button button2\">OFF</button></a></p>");
}
client.println("</div>");

client.println("<div id=\"container\">");
client.println("<p><div class=\"textbox mytext\">DEVICE 3</div>");

if (relay3State == "off") {
client.println("<a href=\"/relay3/on\"><button class=\"button\">ON</button></a></p>");
} else {
client.println("<a href=\"/relay3/off\"><button class=\"button button2\">OFF</button></a></p>");
}
client.println("</div>");

client.println("<div id=\"container\">");
client.println("<p><div class=\"textbox mytext\">DEVICE 4</div>");

if (relay4State == "off") {
client.println("<a href=\"/relay4/on\"><button class=\"button\">ON</button></a></p>");
} else {
client.println("<a href=\"/relay4/off\"><button class=\"button button2\">OFF</button></a></p>");
}
client.println("</div>");

client.println("</body></html>");

client.println();

break;
} else {
currentLine = "";
}
} else if (c != '\r') {
currentLine += c;
}
}
}

header = "";

client.stop();
Serial.println("Client disconnected.");
Serial.println("");
}
}
